@@ -16,6 +16,7 @@
 
 #include <signal.h>
 #include <gnome.h>
+#include <liboaf/oaf.h>
 
 #include <X11/Xlib.h>
 
@@ -24,7 +25,7 @@ PortableServer_POA        __bonobo_poa;
 PortableServer_POAManager __bonobo_poa_manager = NULL;
 
 /**
- * bonobo_exception_get_txt:
+ * bonobo_exception_get_text:
  * @ev: the corba environment.
  * 
  * Returns a user readable description of the exception, busks
@@ -34,7 +35,7 @@ PortableServer_POAManager __bonobo_poa_manager = NULL;
  * and when. NULL is never returned.
  **/
 char *
-bonobo_exception_get_txt (CORBA_Environment *ev)
+bonobo_exception_get_text (CORBA_Environment *ev)
 {
 	g_return_val_if_fail (ev != NULL, NULL);
 
@@ -64,7 +65,7 @@ bonobo_exception_get_txt (CORBA_Environment *ev)
 		return g_strdup (_("The User canceled the save"));
 
 	/* Bonobo::GenericFactory */
-	else if (!strcmp (ev->_repo_id, ex_Bonobo_GenericFactory_CannotActivate))
+	else if (!strcmp (ev->_repo_id, ex_GNOME_ObjectFactory_CannotActivate))
 		return g_strdup (_("Cannot activate object from factory"));
 
 	/* Bonobo::Stream */
@@ -101,6 +102,19 @@ bonobo_exception_get_txt (CORBA_Environment *ev)
 	else if (!strcmp (ev->_repo_id, ex_Bonobo_Persist_FileNotFound))
 		return g_strdup (_("stream not found"));
 
+	/* Bonobo::Moniker */
+	else if (!strcmp (ev->_repo_id, ex_Bonobo_Moniker_InterfaceNotFound))
+		return g_strdup (_("Moniker interface cannot be found"));
+
+	else if (!strcmp (ev->_repo_id, ex_Bonobo_Moniker_TimeOut))
+		return g_strdup (_("Moniker activation timed out"));
+		
+	else if (!strcmp (ev->_repo_id, ex_Bonobo_Moniker_InvalidSyntax))
+		return g_strdup (_("Syntax error within moniker"));
+
+	else if (!strcmp (ev->_repo_id, ex_Bonobo_Moniker_UnknownPrefix))
+		return g_strdup (_("Moniker has an unknown moniker prefix"));
+
 	else
 		return g_strdup_printf ("Unknown CORBA exception id: '%s'", ev->_repo_id);
 }
