@@ -68,6 +68,10 @@ Bonobo_Unknown           bonobo_object_corba_objref           (BonoboObject
 /*
  * Gnome Object Life Cycle
  */
+Bonobo_Unknown           bonobo_object_dup_ref                (Bonobo_Unknown          object,
+							       CORBA_Environment      *ev);
+void                     bonobo_object_release_unref          (Bonobo_Unknown          object,
+							       CORBA_Environment      *ev);
 void                     bonobo_object_ref                    (BonoboObject           *object);
 void                     bonobo_object_unref                  (BonoboObject           *object);
 POA_Bonobo_Unknown__epv *bonobo_object_get_epv                (void);
