@@ -10,12 +10,7 @@
 
 #include <config.h>
 #include <gnome.h>
-
-#if USING_OAF
 #include <liboaf/liboaf.h>
-#else
-#include <libgnorba/gnorba.h>
-#endif
 
 #include <bonobo.h>
 
@@ -293,6 +288,11 @@ view_create_menus (view_data_t *view_data)
 	 */
 	bonobo_ui_handler_set_container (uih, remote_uih);
 
+	/*
+	 * Unref the UI handler we have been passed.
+	 */
+	bonobo_object_release_unref (remote_uih, NULL);
+
 	/*
 	 * Create our menu entries.
 	 */
@@ -647,16 +647,9 @@ embeddable_factory (BonoboEmbeddableFactory *this,
 static void
 init_simple_mines_factory (void)
 {
-#if USING_OAF
 	factory = bonobo_embeddable_factory_new (
 	 "OAFIID:bonobo_application-x-mines_factory:79eddfb6-12fd-4588-a02c-3eb50e67137d",
 		embeddable_factory, NULL);
-
-#else
-	factory = bonobo_embeddable_factory_new (
-		"embeddable-factory:application-x-mines",
-		embeddable_factory, NULL);
-#endif
 }
 
 static void
