@@ -237,12 +237,8 @@ buffer_create (const char *component_goad_id)
 	BonoboClientSite *client_site;
 	BonoboObjectClient *server;
 
-#if USING_OAF
-	server = bonobo_object_activate_with_oaf_id (component_goad_id, 0);
-#else
-	server = bonobo_object_activate_with_goad_id (NULL, component_goad_id, 
-						     0, NULL);
-#endif
+	server = bonobo_object_activate (component_goad_id, 0);
+
 	if (!server) {
 		g_warning("Launching component failed");
 		return NULL;
