@@ -50,7 +50,7 @@ ls_command ()
 {
 	EFSDir *dir;
 	EFSDirEntry *de;
-	const char* name = strtok (NULL, " \t\n");
+	const char *name = strtok (NULL, " \t\n");
 
 	if (name) name = strdup(full_path(name));
 	else name = path;
@@ -92,9 +92,9 @@ mv_command ()
 static void
 rm_command ()
 {
-	const char* name;
+	const char *name;
 
-	name= strtok (NULL, " \t\n");
+	name = strtok (NULL, " \t\n");
 
 	if (!name) {
 		fprintf (stderr, "usage: rm filename\n");
@@ -103,19 +103,66 @@ rm_command ()
 
 	name = strdup(full_path(name));
 
-	if (efs_erase(root, name)) {
-		fprintf(stderr,"rm failed (%s)\n",name);
+	if (efs_erase(root, name))
+		fprintf(stderr,"rm failed (%s)\n", name);
+
+}
+
+static void
+get_command ()
+{
+	const char *name;
+	const char *lname;
+	FILE    *fdest;
+	EFSFile *fsrc;
+
+	name = strtok (NULL, " \t\n");
+
+	if (!name) {
+		fprintf (stderr, "usage: get filename\n");
+		return;
 	}
 
+	name = strdup (full_path (name));
+
+	if (!(fsrc = efs_file_open (root, name, EFS_READ))) {
+		fprintf (stderr,"efs open failed (%s)\n", name);
+		return;
+	}
+	
+	lname = strrchr (name, '/');
+	if (!lname)
+		lname = name;
+	else
+		lname++;
+	if (!(fdest = fopen (lname, "wb+"))) {
+		fprintf (stderr,"open failed (%s)\n", lname);
+		efs_file_close (fsrc);
+		return;
+	}
+
+	while (1) {
+		char   buffer [1024];
+		gint32 len;
+
+		len = efs_file_read (fsrc, buffer, 1024);
+		if (len <= 0)
+			break;
+
+		fwrite (buffer, len, 1, fdest);
+	}
+
+	efs_file_close (fsrc);
+	fclose (fdest);
 }
 
 static void
 mkdir_command ()
 {
-	const char* name;
+	const char *name;
 	EFSDir *dir;
 
-	name= strtok (NULL, " \t\n");
+	name = strtok (NULL, " \t\n");
 
 	if (!name) {
 		fprintf (stderr, "usage: mkdir dirname\n");
@@ -125,7 +172,7 @@ mkdir_command ()
 	name = strdup(full_path(name));
 
 	if (!(dir = efs_dir_open(root, name, EFS_CREATE|EFS_EXCL))) {
-		fprintf(stderr,"mkdir failed (%s)\n",name);
+		fprintf(stderr,"mkdir failed (%s)\n", name);
 	} else efs_dir_close (dir);
 }
 
@@ -177,6 +224,7 @@ help_command ()
 	printf("Available commands:\n");
 	printf("ls             list directory contents\n");
 	printf("cd dir         change directory\n");
+	printf("get file       extract a file\n");
 	printf("mv old new     move file or directory\n");
 	printf("rm name        delete a file or directory\n");
 	printf("mkdir name     create a directory\n");
@@ -197,10 +245,10 @@ add_file_or_dir (gchar *name)
 	DIR *d;
 	struct dirent *de;
 
-	printf("ADD %s\n",name);
+	printf("ADD %s\n", name);
 
 	if (lstat(name,&sb) == -1) {
-		printf("add %s failed!\n",name);
+		printf("add %s failed!\n", name);
 		return;
 	}
 
@@ -235,7 +283,7 @@ add_file_or_dir (gchar *name)
 		return;
 	}
 
-	printf("add %s failed!\n",name);
+	printf("add %s failed!\n", name);
 }
 
 static void
@@ -301,6 +349,8 @@ main(int argc, char *argv[])
 				mv_command ();
 			} else if (strcmp (cmd, "cd") == 0) {
 				cd_command ();
+			} else if (strcmp (cmd, "get") == 0) {
+				get_command ();
 			} else if (strcmp (cmd, "rm") == 0) {
 				rm_command ();
 			} else if (strcmp (cmd, "mkdir") == 0) {
