@@ -10,12 +10,7 @@
 
 #include <config.h>
 #include <gnome.h>
-
-#if USING_OAF
 #include <liboaf/liboaf.h>
-#else
-#include <libgnorba/gnorba.h>
-#endif
 
 #include <bonobo.h>
 #include <bonobo/bonobo-print.h>
@@ -709,15 +704,9 @@ init_simple_paint_factory (void)
 	 * component, it will ask the factory to create one, and the
 	 * factory will invoke our embeddable_factory() function.
 	 */
-#if USING_OAF
          return bonobo_generic_factory_new (
 			    "OAFIID:paint_component_simple_factory:301d4c2f-3f2b-404d-99e5-3fde72a1e601",
 			     embeddable_factory, NULL);
-#else
-         return bonobo_generic_factory_new (
-			     "embeddable-factory:paint-component-simple",
-			     embeddable_factory, NULL);  
-#endif
 }
 
 static void
@@ -728,19 +717,10 @@ init_server_factory (int argc, char **argv)
 
 	CORBA_exception_init (&ev);
 
-#if USING_OAF
         gnome_init_with_popt_table("bonobo-simple-paint", VERSION,
 				   argc, argv,
 				   oaf_popt_options, 0, NULL); 
 	orb = oaf_init (argc, argv);
-#else
-	gnome_CORBA_init_with_popt_table (
-		"bonobo-simple-paint", VERSION,
-		&argc, argv, NULL, 0, NULL, GNORBA_INIT_SERVER_FUNC, &ev);
-
-	CORBA_exception_free (&ev);
-	orb = gnome_CORBA_ORB ();
-#endif
 
 	if (bonobo_init (orb, NULL, NULL) == FALSE)
 		g_error (_("Could not initialize Bonobo!"));
