@@ -155,32 +155,11 @@ bonobo_storage_fs_construct (BonoboStorageFS *storage,
 	return BONOBO_STORAGE (storage);
 }
 
-static Bonobo_Storage
-create_bonobo_storage_fs (BonoboObject *object)
-{
-	POA_Bonobo_Storage *servant;
-	CORBA_Environment ev;
-
-	servant = (POA_Bonobo_Storage *) g_new0 (BonoboObjectServant, 1);
-	servant->vepv = &bonobo_storage_vepv;
-
-	CORBA_exception_init (&ev);
-	POA_Bonobo_Storage__init ((PortableServer_Servant) servant, &ev);
-	if (ev._major != CORBA_NO_EXCEPTION){
-                g_free (servant);
-		CORBA_exception_free (&ev);
-		return CORBA_OBJECT_NIL;
-        }
-	CORBA_exception_free (&ev);
-
-	return (Bonobo_Storage) bonobo_object_activate_servant (object, servant);
-}
-
 /*
  * Creates the Gtk object and the corba server bound to it
  */
-static Bonobo_Storage
-do_bonobo_storage_fs_create (char *path)
+static BonoboStorage *
+do_bonobo_storage_fs_create (const char *path)
 {
 	BonoboStorageFS *storage_fs;
 	Bonobo_Storage corba_storage;
@@ -188,14 +167,15 @@ do_bonobo_storage_fs_create (char *path)
 	storage_fs = gtk_type_new (bonobo_storage_fs_get_type ());
 	storage_fs->path = g_strdup (path);
 	
-	corba_storage = create_bonobo_storage_fs (
+	corba_storage = bonobo_storage_corba_object_create (
 		BONOBO_OBJECT (storage_fs));
 	if (corba_storage == CORBA_OBJECT_NIL){
-		gtk_object_destroy (GTK_OBJECT (storage_fs));
+		bonobo_object_unref (BONOBO_OBJECT (storage_fs));
 		return NULL;
 	}
 
-	return (Bonobo_Storage) bonobo_storage_construct (BONOBO_STORAGE (storage_fs), corba_storage);
+	return bonobo_storage_construct
+		(BONOBO_STORAGE (storage_fs), corba_storage);
 }
 
 /** 
@@ -239,7 +219,7 @@ bonobo_storage_fs_open (const char *path, gint flags, gint mode)
 		}
 	}
 
-	return BONOBO_STORAGE (do_bonobo_storage_fs_create (g_strdup (path)));
+	return do_bonobo_storage_fs_create (path);
 }
 
 /*
