@@ -18,6 +18,7 @@
  *
  *----------------------------------------------------------------------*/
 
+#include <config.h>
 #include <gnome.h>
 #include <stdlib.h>
 #include <string.h>
@@ -299,7 +300,7 @@ create_file_selection(GtkWidget *unused1,
 
   if (!window)
     {
-      window = gtk_file_selection_new ("file selection dialog");
+      window = gtk_file_selection_new (_("file selection dialog"));
 
       gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (window));
 
@@ -353,7 +354,7 @@ setup_idl_window()
 	load_btn = 
 		gtk_button_new_with_label_and_pixmap (
 			vbox,
-			"Open IDL File...",
+			_("Open IDL File..."),
 			GNOME_STOCK_PIXMAP_OPEN);
 
 	gtk_signal_connect (GTK_OBJECT (load_btn), "clicked",
